@@ -12,6 +12,7 @@ import math
 import time
 from collections import defaultdict
 from collections.abc import Hashable, Iterable, Iterator, Sequence
+from dataclasses import dataclass, field
 from enum import IntEnum
 from functools import cached_property
 from random import Random
@@ -26,8 +27,6 @@ from typing import (
     overload,
 )
 
-import attr
-
 from hypothesis.errors import (
     CannotProceedScopeT,
     ChoiceTooLarge,
@@ -71,6 +70,7 @@ from hypothesis.internal.intervalsets import IntervalSet
 from hypothesis.internal.observability import PredicateCounts
 from hypothesis.reporting import debug_report
 from hypothesis.utils.conventions import not_set
+from hypothesis.utils.deprecation import note_deprecation
 from hypothesis.utils.threading import ThreadLocal
 
 if TYPE_CHECKING:
@@ -82,7 +82,6 @@ if TYPE_CHECKING:
 
 def __getattr__(name: str) -> Any:
     if name == "AVAILABLE_PROVIDERS":
-        from hypothesis._settings import note_deprecation
         from hypothesis.internal.conjecture.providers import AVAILABLE_PROVIDERS
 
         note_deprecation(
@@ -120,9 +119,9 @@ class Status(IntEnum):
         return f"Status.{self.name}"
 
 
-@attr.s(slots=True, frozen=True)
+@dataclass(slots=True, frozen=True)
 class StructuralCoverageTag:
-    label: int = attr.ib()
+    label: int
 
 
 STRUCTURAL_COVERAGE_CACHE: dict[int, StructuralCoverageTag] = {}
@@ -568,27 +567,27 @@ class DataObserver:
         pass
 
 
-@attr.s(slots=True)
+@dataclass(slots=True, frozen=True)
 class ConjectureResult:
     """Result class storing the parts of ConjectureData that we
     will care about after the original ConjectureData has outlived its
     usefulness."""
 
-    status: Status = attr.ib()
-    interesting_origin: InterestingOrigin | None = attr.ib()
-    nodes: tuple[ChoiceNode, ...] = attr.ib(eq=False, repr=False)
-    length: int = attr.ib()
-    output: str = attr.ib()
-    expected_exception: BaseException | None = attr.ib()
-    expected_traceback: str | None = attr.ib()
-    has_discards: bool = attr.ib()
-    target_observations: TargetObservations = attr.ib()
-    tags: frozenset[StructuralCoverageTag] = attr.ib()
-    spans: Spans = attr.ib(repr=False, eq=False)
-    arg_slices: set[tuple[int, int]] = attr.ib(repr=False)
-    slice_comments: dict[tuple[int, int], str] = attr.ib(repr=False)
-    misaligned_at: MisalignedAt | None = attr.ib(repr=False)
-    cannot_proceed_scope: CannotProceedScopeT | None = attr.ib(repr=False)
+    status: Status
+    interesting_origin: InterestingOrigin | None
+    nodes: tuple[ChoiceNode, ...] = field(repr=False, compare=False)
+    length: int
+    output: str
+    expected_exception: BaseException | None
+    expected_traceback: str | None
+    has_discards: bool
+    target_observations: TargetObservations
+    tags: frozenset[StructuralCoverageTag]
+    spans: Spans = field(repr=False, compare=False)
+    arg_slices: set[tuple[int, int]] = field(repr=False)
+    slice_comments: dict[tuple[int, int], str] = field(repr=False)
+    misaligned_at: MisalignedAt | None = field(repr=False)
+    cannot_proceed_scope: CannotProceedScopeT | None = field(repr=False)
 
     def as_result(self) -> "ConjectureResult":
         return self
@@ -647,12 +646,12 @@ class ConjectureData:
         self.overdraw = 0
         self._random = random
 
-        self.length = 0
-        self.index = 0
-        self.output = ""
-        self.status = Status.VALID
-        self.frozen = False
-        self.testcounter = threadlocal.global_test_counter
+        self.length: int = 0
+        self.index: int = 0
+        self.output: str = ""
+        self.status: Status = Status.VALID
+        self.frozen: bool = False
+        self.testcounter: int = threadlocal.global_test_counter
         threadlocal.global_test_counter += 1
         self.start_time = time.perf_counter()
         self.gc_start_time = gc_cumulative_time()
@@ -660,8 +659,8 @@ class ConjectureData:
         self.interesting_origin: InterestingOrigin | None = None
         self.draw_times: dict[str, float] = {}
         self._stateful_run_times: dict[str, float] = defaultdict(float)
-        self.max_depth = 0
-        self.has_discards = False
+        self.max_depth: int = 0
+        self.has_discards: bool = False
 
         self.provider: PrimitiveProvider = (
             provider(self, **provider_kw) if isinstance(provider, type) else provider
@@ -684,9 +683,8 @@ class ConjectureData:
         # examples for reporting purposes.
         self.__spans: Spans | None = None
 
-        # We want the top level span to have depth 0, so we start
-        # at -1.
-        self.depth = -1
+        # We want the top level span to have depth 0, so we start at -1.
+        self.depth: int = -1
         self.__span_record = SpanRecord()
 
         # Slice indices for discrete reportable parts that which-parts-matter can
